import WebSocket from 'isomorphic-ws';
import { CloseEvent, ErrorEvent, MessageEvent, OpenEvent } from 'ws';
/**
 * @author Onur Gürsoy
 */
export declare class WebsocketClient implements IWebsocketClient {
    debug: boolean;
    readonly reconnectInterval = 1000;
    readonly timeoutInterval = 2000;
    readyState: number;
    forcedClose: boolean;
    timedOut: boolean;
    readonly protocols: string[];
    webSocket?: WebSocket;
    readonly url: string;
    onOpen: (ev: OpenEvent) => void;
    onClose: (ev: CloseEvent) => void;
    onConnecting: () => void;
    onMessage: (ev: MessageEvent) => void;
    onError: (ev: ErrorEvent) => void;
    constructor(url: string, protocols?: string[]);
    connect: (reconnectAttempt: boolean) => void;
    send: (data: string) => void;
    /**
     * Returns boolean, whether websocket was FORCEFULLY closed.
     */
    close: () => boolean;
    /**
     * Additional public API method to refresh the connection if still open (close, re-open).
     * For example, if the app suspects bad data / missed heart beats, it can try to refresh.
     *
     * Returns boolean, whether websocket was closed.
     */
    refresh: () => boolean;
    private log;
}
export declare type IWebsocketClient = {
    refresh: () => boolean;
    close: () => boolean;
    send: (data: string) => void;
    connect: (reconnectAttempt: boolean) => void;
    onOpen: (ev: OpenEvent) => void;
    onClose: (ev: CloseEvent) => void;
    onConnecting: () => void;
    onMessage: (ev: MessageEvent) => void;
    onError: (ev: ErrorEvent) => void;
    protocols?: string[];
    webSocket?: WebSocket;
    url?: string;
};
