import { ApiMetadata } from './ApiMetadata';
import { MetaDataObjectType } from './MetaDataObjectType';
import { SparseClause } from './SparseClause';
/**
 * Juracus Analysis results for a specific criterion.
 *
 * @author Onur Gürsoy
 */
export declare class AnalysisResults {
    readonly metadata: {
        [p: string]: ApiMetadata<MetaDataObjectType>;
    };
    readonly pId: string;
    readonly clauses: SparseClause[];
    readonly foundFlag: boolean;
    readonly id: string;
    /**
     * Constructs a new {@link AnalysisResults} object containing the analysis results for the specified criterion.
     *
     * @param pId - UUID of the {@link Criterion} the result belongs to.
     * @param clauses     - {@link Array} of analyzed texts. Defaults to an empty {@link Array} if {@code null}.
     * @param foundFlag   - {@link Boolean} specifying whether or not at least one as relevant classified clause was found.
     * @param metadata    - {@link Map} for additional metadata. Defaults to an empty {@link Map} if {@code null}.
     */
    constructor(metadata: {
        [p: string]: ApiMetadata<MetaDataObjectType>;
    }, pId: string, clauses?: SparseClause[], foundFlag?: boolean);
    /**
     * Returns the {@link ApiCriterionMetadataKey}s for which contents are available.
     *
     * @return {@link Set} of {@link ApiCriterionMetadataKey}s for which contents are available.
     */
    readonly availableMetadataKeys: () => string[];
}
