import { ApiStage } from './ApiStage';
/**
 * Error container for debugging purposes.
 *
 * @author Onur Gürsoy
 */
export declare class ApiError extends Error {
    readonly name: string;
    readonly description: string;
    readonly errorCode: number | undefined;
    readonly source: ApiStage;
    static readonly serialVersionUID: number;
    /**
     * Unique identifier for this specific {@link ApiError} object. This is not an identifier for the error type like the error code.
     * @private
     */
    readonly id: string;
    /**
     * Constructs an {@link ApiError} object with the specified id (which is usually generated randomly), a name, description, error code and its source.
     *
     * @param name - Name of this error or short description.
     * @param description - Detailed description for the error
     * @param errorCode - Error code to identify the type of error.
     * @param source - Source where the error occurred.
     */
    constructor(name: string, description: string, errorCode: number | undefined, source: ApiStage);
}
