export declare class ApiOption {
    readonly isEnabledByDefault: boolean;
    readonly value: string;
    /**
     * If enabled this option requests the Juracus AI to include clauses which are classified as relevant by the Juracus AI. The confidence for this texts might be undefined if the {@link #CONFIDENCE} option is disabled.
     */
    static readonly RELEVANT_CLAUSES: ApiOption;
    /**
     * If enabled this option requests the Juracus AI to include clauses which are classified as irrelevant by the Juracus AI. The confidence for this texts might be undefined if the {@link #CONFIDENCE} option is disabled.
     */
    static readonly IRRELEVANT_CLAUSES: ApiOption;
    /**
     * If enabled this option requests the Juracus AI to include confidence values for each classified text passage.
     */
    static readonly CONFIDENCE: ApiOption;
    /**
     * If enabled this option requests the Juracus AI to include a {@link Boolean} specifying whether or not a relevant text for the specified criterion has been found.
     * Using this option is equivalent to using the {@link #RELEVANT_CLAUSES} option and checking whether or not the collection of found texts is not empty.
     */
    static readonly FOUND_FLAG: ApiOption;
    /**
     * If enabled this option requests the Juracus AI to include additional meta information in the response.
     */
    static readonly METADATA: ApiOption;
    /**
     * Returns all available options
     */
    static readonly values: () => ApiOption[];
    /**
     * Constructs a new {@link ApiOption} object with the specified default status.
     * @param value Displayname of option. Needs to be there to serialize properly.
     * @param isEnabledByDefault - Boolean specifying whether or not the constructed {@link ApiOption} should be enabled on default.
     */
    private constructor();
    toJSON(): string;
}
