export declare class Category {
    readonly id: string;
    readonly name: string;
    /**
     * Security - Category containing all criteria which are connected to information security.
     */
    static readonly SECURITY: Category;
    /**
     * Contract Frame - Category containing all criteria which define basic conditions the contract is subject to.
     */
    static readonly FRAME: Category;
    /**
     * Contract Cancellation and Liability - Category containing all criteria which are part of the contract cancellation or describe liability/warranty or contract penalties.
     */
    static readonly CANCELLATION_AND_LIABILITY: Category;
    /**
     * Constructs a new {@link Category} based on the given UUID as identifier and name.
     *
     * @param id   - UUID of the constructed {@link Category}.
     * @param name - Name or short description of the {@link Category}.
     */
    private constructor();
    static readonly values: () => Category[];
    /**
     * Returns a {@link Set} of all available categories.
     *
     * @return {@link Set} of {@link Category} objects.
     */
    static readonly set: () => Set<Category>;
    /**
     * Resolves the specified UUID representing a {@link Category}'s unique identifier to a {@link Category} object.
     *
     * @param uuid - Unique identifier of the {@link Category} to resolve.
     * @return {@link Category} with the specified UUID.
     * @throws Error if no {@link Category} with the specified id exists.
     * @throws Error if given id is not valid UUID
     */
    static readonly tryFindById: (uuid: string) => Category;
}
