import { Classification } from './Classification';
import { SparseClause } from './SparseClause';
import { TextSpan } from './TextSpan';
/**
 * Container class for analyzed text clauses.
 *
 * @author Onur Gürsoy
 */
export declare class Clause extends SparseClause {
    /**
     * Classified text clause.
     */
    readonly clauseText: string;
    /**
     *
     * Constructs a new {@link Clause} defining which part of a text is marked as relevant to which confidence.
     *
     * @param clauseText     Classified text clause
     * @param span           Boundaries of the marked text.
     * @param classification Binary classification of the Juracus AI which marks clauses as relevant or irrelevant for a specified criterion.
     * @param confidence     Confidence of the Juracus AI that the marked text is relevant to the criterion this clause belongs to. This value may be 0.0 if the option {@link ApiOption#CONFIDENCE} is disabled.
     */
    constructor(span: TextSpan, classification: Classification, confidence: number, clauseText: string);
    /**
     * Creates a {@link SparseClause} from this {@link Clause}.
     *
     * @return {@link SparseClause} containing the same {@link TextSpan} and confidence value as this {@link Clause} but saving memory by removing the text.
     */
    readonly makeSparse: () => SparseClause;
}
