export declare class PhoneNumber {
    private readonly _iDD;
    private readonly _cCC;
    private readonly _number;
    constructor(_iDD: string, _cCC: string, _number: string);
    /**
     * Checks whether or not this {@link PhoneNumber} has an International Direct Dialing Code (IDD).
     *
     * @return {@code true} if an International Direct Dialing Code has been provided and {@code false} if the IDD was omitted or is specified to the current location of the caller (denoted by "{@code +}").
     */
    readonly hasInternationalDirectDialingCode: () => boolean;
    /**
     * Checks whether or not this {@link PhoneNumber} has a Country Calling Code.
     *
     * @return {@code true} if a Country Calling Code has been provided explicitly and {@code false} if it was omitted using the zero digit 0 at the beginning of the number.
     */
    readonly hasCountryCallingCode: () => boolean;
    /**
     * Returns the Country Calling Code of this {@link PhoneNumber}.
     *
     * @return The Country Calling Code as {@link String} if it has been provided explicitly. Otherwise {@code "0"} is returned.
     */
    get cCC(): string;
    /**
     * Returns the International Direct Dialing Code (IDD) for this {@link PhoneNumber} if provided. Otherwise "{@code +}" will be returned denoting the IDD depents on the current location of the caller.
     *
     * @return International Direct Dialing Code (IDD) as {@link String} which consists of 2, 3 or 4 digits or is equal to {@code "+"}.
     */
    get iDD(): string;
    /**
     * Many mobile phone numbers have a prefix based on their cellular/phone provider. This method tries to extract the provider based on known prefixes.
     *
     * @return Name of the provider or {@code null} if unknown.
     */
    findProvider: () => string;
}
