import { Classification } from './Classification';
import { TextSpan } from './TextSpan';
/**
 * Memory saving implementation of a binary classified text passage.
 *
 * @author Onur Gürsoy
 */
export declare class SparseClause {
    readonly span: TextSpan;
    readonly confidence: number;
    readonly classification: Classification;
    /**
     * Constructs a new {@link SparseClause} defining which part of a text is marked as relevant to which confidence.
     *
     * @param span           Boundaries of the marked text.
     * @param classification Binary classification of the Juracus AI which marks clauses as relevant or irrelevant for a specified criterion.
     * @param confidence     Confidence of the Juracus AI that the marked text is relevant to the criterion this clause belongs to. This value may be 0.0 if the option {@link ApiOption#CONFIDENCE} is disabled.
     */
    constructor(span: TextSpan, confidence: number, classification: Classification);
    /**
     * Returns whether or not the clause is relevant to the criterion this clause belongs to.
     */
    readonly isRelevant: () => boolean;
    /**
     * Returns whether or not the clause is irrelevant to the criterion this clause belongs to.
     */
    readonly isIrrelevant: () => boolean;
}
