/**
 *  Text boundary based on character indices.
 *  @author Onur Gürsoy
 */
export declare class TextSpan {
    /**
     *  Index of the first character belonging to this {@link TextSpan}.
     */
    readonly beginIndex: number;
    /**
     *  Index of the last character belonging to this {@link TextSpan} + 1.
     */
    readonly endIndex: number;
    /**
     * Constructs a new {@link TextSpan} object marking the text area beginning at the beginIndex and ending at the endIndex.
     * @param beginIndex  Index of the first character belonging to this {@link TextSpan}.
     * @param endIndex    Index of the last character belonging to this {@link TextSpan} + 1.
     */
    constructor(beginIndex: number, endIndex: number);
    /**
     * Return lenght of this {@link TextSpan}
     */
    readonly length: () => number;
    private readonly contains;
    /**
     * Shows if given {@link TextSpan} intersects with this one
     * @param span Which to check intersection
     */
    readonly intersects: (span: TextSpan) => boolean;
    /**
     * @param text - Text to retrieve the substring from.
     * @return Substring within the text starting at the begin index and ending at the end index. This method is equivalent to calling {@link String#substring(int, int)} where the first parameter is equal to {@link #beginIndex} and the second
     * parameter is equal to {@link #endIndex}.
     */
    readonly substring: (text: string) => string;
}
