import { ApiOptions } from './ApiOptions';
import { DataFormat } from './DataFormat';
/**
 * Request send to the Juracus Document Converter in order to create a machine-readable file for the Juracus AI to analyze.
 *
 * @author Onur Gürsoy
 */
export declare type ApiConvertRequest = {
    /**
     * Mapping from each {@link Criterion} to analyze to options for the specific analysis.
     */
    readonly tasks: {
        [p: string]: ApiOptions;
    };
    /**
     * Used to differentiate between production and development environments.
     */
    readonly gatewayStage: string;
    /**
     * Unique identifier pointing to the API user such that the response can be send after finishing the conversion and analysis.
     */
    readonly connectionId: string;
    /**
     * URL pointing to the document the converter should convert.
     */
    readonly s3FileUrl: string;
    /**
     * Format of the document to convert.
     */
    readonly dataFormat: DataFormat;
};
