/**
 * Enum for all available meta data keys.
 *
 * @author Onur Gürsoy
 */
export declare enum ApiCriterionMetadataKey {
    /**
     * Brings dates from text in various formats (see below) in machine readable form.
     * <ul>
     * <li>{@code D.M.YY}</li>
     * <li>{@code D.M.YYYY}</li>
     * <li>{@code DD.MM.YY}</li>
     * <li>{@code DD.MM.YYYY}</li>
     * <li>{@code D-M-YY}</li>
     * <li>{@code D-M-YYYY}</li>
     * <li>{@code DD-MM-YY}</li>
     * <li>{@code DD-MM-YYYY}</li>
     * <li>{@code D/M/YY}</li>
     * <li>{@code D/M/YYYY}</li>
     * <li>{@code DD/MM/YY}</li>
     * <li>{@code DD/MM/YYYY}</li>
     * </ul>
     */
    DATES = "DATES",
    /**
     * Brings amounts of money from text into a machine readable format. The supported text formats are:
     * <ul>
     * <li>{@code ##########} (Integer representation without decimal places)</li>
     * <li>{@code #######,##} (German notation without grouping)</li>
     * <li>{@code ###.###,##} (German notation with grouping)</li>
     * <li>{@code ### ###,##} (German notation with spaced grouping)</li>
     * <li>{@code ###'###,##} (German notation with apostrophe grouping)</li>
     * <li>{@code #######.##} (English notation without grouping)</li>
     * <li>{@code ###,###.##} (English notation with grouping)</li>
     * <li>{@code ### ###.##} (English notation with spaced grouping)</li>
     * <li>{@code ###'###.##} (English notation with apostrophe grouping)</li>
     * </ul>
     */
    AMOUNT_OF_MONEY = "AMOUNT_OF_MONEY",
    /**
     * Bring references to legal documents (e.g. "{@code § 55 Abs. 2 RStV}") or references to another section of the analyzed document (e.g. "{@code ... wie in § 3.2 dieser Vereinbarung beschrieben.}") into a machine readable form.
     */
    LEGAL_REFERENCES = "LEGAL_REFERENCES"
}
