/**
 * Enum for all available meta data keys regarding the whole document instead of only certain criteria ({@link Criterion}).
 *
 * @author Onur Gürsoy
 */
export declare enum ApiDocumentMetadataKey {
    /**
     * Phone numbers in various formats parsed from text into a machine readable format.
     * <ul>
     * <li>+49 0123 456789 (space grouping)</li>
     * <li>0123-456789 (dash/minus grouping)</li>
     * <li>0123/456789 (slash grouping)</li>
     * <li>0123/45678-9 (slash and dash/minus grouping)</li>
     * <li>0123/45678 9 (slash and space grouping)</li>
     * <li>0123-45678 9 (dash and space grouping)</li>
     * <li>+49 123/45678-9 (space, slash and dash/minus grouping)</li>
     * <li>...</li>
     * </ul>
     */
    PHONE_NUMBERS = "PHONE_NUMBERS",
    /**
     * E-Mail addresses within the document.
     */
    EMAILS = "EMAILS",
    /**
     * Keywords belonging to various criteria which can be used in case not all text passages where found.
     */
    KEYWORDS = "KEYWORDS"
}
