/**
 * A {@link Criterion} defines what the Juracus AI has to analyze. For each {@link Criterion} there is a short name {@link #name} and description.
 *
 * @author Onur Gürsoy
 */
export declare class Criterion {
    readonly id: string;
    readonly categoryId: string;
    readonly name: string;
    readonly description: string;
    readonly available: boolean;
    /**
     *  Data erasure and data return
     */
    static readonly DATA_DELETION_AND_RETURN: Criterion;
    /**
     * Data transfer to third parties
     */
    static readonly DATA_TRANSFER_TO_THIRD_PARTIES: Criterion;
    /**
     *  Data transfer to otherwise authorized third parties
     */
    static readonly DATA_TRANSFER_TO_OTHERWISE_AUTHORIZED_THIRD_PARTIES: Criterion;
    /**
     *  Data transfer to partner companies
     */
    static readonly DATA_TRANSFER_TO_PARTNER_COMPANY: Criterion;
    /**
     * Data transfer and usage for an agreed purpose
     */
    static readonly DATA_TRANSFER_FOR_AGGREED_PURPOSE: Criterion;
    /**
     * Data transfer only to third parties which underly a non-disclosure aggreement
     */
    static readonly DATA_TRANSFER_UNDER_NDA: Criterion;
    /**
     *  Deadlines
     */
    static readonly DEADLINES: Criterion;
    /**
     * Fines
     */
    static readonly FINES: Criterion;
    /**
     *  Regulations regarding the jurisdiction
     */
    static readonly JURISDICTION_REGULATIONS: Criterion;
    /**
     * Force Majeure
     */
    static readonly FORCE_MAJEURE: Criterion;
    /**
     * Definition of 'information'
     */
    static readonly DEFINITION_OF_INFORMATION: Criterion;
    /**
     * Change of Control
     */
    static readonly CHANGE_OF_CONTROL: Criterion;
    /**
     * Terms
     */
    static readonly TERMS: Criterion;
    /**
     * Regulations regarding loopholes
     */
    static readonly LOOPHOLES: Criterion;
    /**
     * Regulations regarding ordinary jurisdiction
     */
    static readonly ORDINARIY_JURISDICTION: Criterion;
    /**
     * Preamble and objectives of the contract
     */
    static readonly PREAMBLE: Criterion;
    /**
     * Regulations regarding arbitration
     */
    static readonly ARBITRATION: Criterion;
    /**
     * Written form requirements
     */
    static readonly WRITTEN_FORM_REQUIREMENTS: Criterion;
    /**
     * Regulations regarding the cancellation of the contract
     */
    static readonly CONTRACT_CANCELLATION: Criterion;
    /**
     * Contractual claims in the even of breach of contract
     */
    static readonly CONTRACTUAL_CLAIMS_BREACH_OF_CONTRACT: Criterion;
    /**
     * Constructs a new {@link Criterion} with the specified parameters.
     *
     * @param id          - UUID of the {@link Criterion}.
     * @param categoryId  - UUID of the {@link Criterion}'s category.
     * @param name        - Name of the {@link Criterion}.
     * @param description - Detailed description of the {@link Criterion}.
     * @param available   - Flag specifying for which services the {@link Criterion} is available.
     */
    private constructor();
}
